@@ -4,7 +4,7 @@
 {-# LANGUAGE RankNTypes                 #-}
 {- |
 Module      : Text.GridTable.Trace
-Copyright   : © 2022 Albert Krewinkel
+Copyright   : © 2022-2023 Posit Software, PBC
 License     : MIT
 Maintainer  : Albert Krewinkel <albert@zeitkraut.de>
 
@@ -30,7 +30,7 @@ import Data.List (foldl')
 import Data.Maybe (fromMaybe)
 import Data.Set (Set)
 import Data.Text (Text)
-import Text.DocLayout (charWidth)
+import Text.DocLayout (charWidth, realLength)
 import Text.GridTable.ArrayTable
 import qualified Data.Map.Strict as Map
 import qualified Data.Set as Set
@@ -99,7 +99,7 @@ initialTraceInfo = TraceInfo
 -- | Converts a list of lines into a char array.
 toCharGrid :: [Text] -> CharGrid
 toCharGrid lines =
-  let chars = foldr (\t m -> max m (T.length t)) 0 lines -- potential overcount
+  let chars = foldr (\t m -> max m (realLength t)) 0 lines -- potential overcount
       gbounds = ( (CharRow 1, CharCol 1)
                 , (CharRow (length lines), CharCol chars)
                 )
@@ -344,6 +344,7 @@ lastColumn = snd . snd . bounds
 lastRow :: CharGrid -> CharRow
 lastRow = fst . snd . bounds
 
+-- | Forgiving version of scanRight, allowing misaligned line ends
 scanRightRestOfLine :: CharGrid -> CharIndex -> CharRow -> Maybe ColSeps
 scanRightRestOfLine charGrid (_top, left) bottom =
   let  go :: CharCol -> Maybe ColSeps -> Maybe ColSeps
